aboutsummaryrefslogtreecommitdiff
path: root/include/openvswitch
diff options
context:
space:
mode:
authorBen Pfaff <blp@nicira.com>2011-10-05 09:59:51 -0700
committerBen Pfaff <blp@nicira.com>2011-10-12 16:27:09 -0700
commit09ded0ad489630236210a02f2d315816e558d701 (patch)
treeab6fb6575e822d0c6026b4d564fb12ad64a8a25c /include/openvswitch
parent13c0dbe79a50c412721a5df697c6a6303b22d2da (diff)
datapath-protocol: Rename enums for consistency.
Most of the enum tags in this file are lowercased versions of the uppercase enum prefixes (or slightly less abbreviated versions, e.g. "dp" becomes "datapath"). This commit fixes up the others for consistency. Signed-off-by: Ben Pfaff <blp@nicira.com> Acked-by: Jesse Gross <jesse@nicira.com>
Diffstat (limited to 'include/openvswitch')
-rw-r--r--include/openvswitch/datapath-protocol.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/openvswitch/datapath-protocol.h b/include/openvswitch/datapath-protocol.h
index 4e9c32a4..b522edc9 100644
--- a/include/openvswitch/datapath-protocol.h
+++ b/include/openvswitch/datapath-protocol.h
@@ -99,20 +99,20 @@ enum ovs_datapath_attr {
OVS_DP_ATTR_NAME, /* name of dp_ifindex netdev */
OVS_DP_ATTR_UPCALL_PID, /* Netlink PID to receive upcalls */
OVS_DP_ATTR_STATS, /* struct ovs_dp_stats */
- OVS_DP_ATTR_IPV4_FRAGS, /* 32-bit enum ovs_frag_handling */
+ OVS_DP_ATTR_IPV4_FRAGS, /* 32-bit enum ovs_datapath_frag */
__OVS_DP_ATTR_MAX
};
#define OVS_DP_ATTR_MAX (__OVS_DP_ATTR_MAX - 1)
/**
* enum ovs_frag_handling - policy for handling received IPv4 fragments.
* @OVS_DP_FRAG_ZERO: Treat IP fragments as IP protocol 0 and transport ports
* zero.
* @OVS_DP_FRAG_DROP: Drop IP fragments. Do not pass them through the flow
* table or up to userspace.
*/
-enum ovs_frag_handling {
+enum ovs_datapath_frag {
OVS_DP_FRAG_UNSPEC,
OVS_DP_FRAG_ZERO, /* Treat IP fragments as transport port 0. */
OVS_DP_FRAG_DROP /* Drop IP fragments. */
@@ -277,7 +277,7 @@ struct ovs_flow_stats {
uint64_t n_bytes; /* Number of matched bytes. */
};
-enum ovs_key_type {
+enum ovs_key_attr {
OVS_KEY_ATTR_UNSPEC,
OVS_KEY_ATTR_TUN_ID, /* 64-bit tunnel ID */
OVS_KEY_ATTR_IN_PORT, /* 32-bit OVS dp port number */
@@ -431,7 +431,7 @@ enum ovs_userspace_attr {
#define OVS_USERSPACE_ATTR_MAX (__OVS_USERSPACE_ATTR_MAX - 1)
/* Action types. */
-enum ovs_action_type {
+enum ovs_action_attr {
OVS_ACTION_ATTR_UNSPEC,
OVS_ACTION_ATTR_OUTPUT, /* Output to switch port. */
OVS_ACTION_ATTR_USERSPACE, /* Nested OVS_USERSPACE_ATTR_*. */
@@ -99,20 +99,20 @@ enum ovs_datapath_attr {
#define OVS_DP_ATTR_MAX (__OVS_DP_ATTR_MAX - 1)
/**
- * enum ovs_frag_handling - policy for handling received IPv4 fragments.
+ * enum ovs_datapath_frag - policy for handling received IPv4 fragments.
* @OVS_DP_FRAG_ZERO: Treat IP fragments as IP protocol 0 and transport ports
* zero.